@@ -460,7 +460,7 @@ gst_ffmpegdemux_do_seek (GstFFMpegDemux * demux, GstSegment * segment)
   /* get the stream for seeking */
   stream = demux->context->streams[index];
   /* initial seek position */
-  target = segment->position;
+  target = segment->position + demux->start_time;
   /* convert target to ffmpeg time */
   fftarget = gst_ffmpeg_time_gst_to_ff (target, stream->time_base);
 
@@ -503,6 +503,11 @@ gst_ffmpegdemux_do_seek (GstFFMpegDemux * demux, GstSegment * segment)
 
   GST_DEBUG_OBJECT (demux, "seek success, returned %d", seekret);
 
+  if (target > demux->start_time)
+    target -= demux->start_time;
+  else
+    target = 0;
+
   segment->position = target;
   segment->time = target;
   segment->start = target;
@@ -1488,17 +1493,10 @@ gst_ffmpegdemux_loop (GstFFMpegDemux * demux)
         ((GstFFMpegDemuxClass *) (G_OBJECT_GET_CLASS (demux)))->in_plugin->name;
     GstMapInfo map;
 
-    if (strcmp (plugin_name, "gif") == 0) {
-      src.data[0] = pkt.data;
-      src.data[1] = NULL;
-      src.data[2] = NULL;
-      src.linesize[0] = avstream->codec->width * 3;
-    } else {
-      GST_WARNING ("Unknown demuxer %s, no idea what to do", plugin_name);
-      gst_ffmpeg_avpicture_fill (&src, pkt.data,
-          avstream->codec->pix_fmt, avstream->codec->width,
-          avstream->codec->height);
-    }
+    GST_WARNING ("Unknown demuxer %s, no idea what to do", plugin_name);
+    gst_ffmpeg_avpicture_fill (&src, pkt.data,
+        avstream->codec->pix_fmt, avstream->codec->width,
+        avstream->codec->height);
 
     gst_buffer_map (outbuf, &map, GST_MAP_WRITE);
     gst_ffmpeg_avpicture_fill (&dst, map.data,
@@ -2084,7 +2082,10 @@ gst_ffmpegdemux_register (GstPlugin * plugin)
         !strcmp (in_plugin->name, "yuv4mpegpipe") ||
         !strcmp (in_plugin->name, "pva") ||
         !strcmp (in_plugin->name, "mpc") ||
-        !strcmp (in_plugin->name, "mpc8") || !strcmp (in_plugin->name, "ivf"))
+        !strcmp (in_plugin->name, "mpc8") ||
+        !strcmp (in_plugin->name, "ivf") ||
+        !strcmp (in_plugin->name, "brstm") ||
+        !strcmp (in_plugin->name, "bfstm") || !strcmp (in_plugin->name, "gif"))
       rank = GST_RANK_MARGINAL;
     else {
       GST_DEBUG ("ignoring %s", in_plugin->name);
